
def zip_longest(*args, fillvalue=()):
    """
    Like zip(), returns an iterator that aggregates elements from each of the iterables.
    The iterator stops when the shortest iterable is exhausted, unlike zip(), which stops when the longest is exhausted.

    :param args: An arbitrary number of iterables.
    :param fillvalue: Value to use for missing values from shorter iterables.
    :return: An iterator that aggregates elements from each of the iterables.
    """
    iters = [iter(iterable) for iterable in args]
    while True:
        result = []
        for it in iters:
            try:
                result.append(next(it))
            except StopIteration:
                return
        yield tuple(result)



